@@ -1,6 +1,6 @@
 demographics <-
-function(ip.address,session) {
-    demographics.url<-paste(session$de,"demographics.json?ip=",ip.address,"&apikey=",session$api.key,sep="")
+function(ip.address) {
+    demographics.url<-paste(.InfochimpsEnv$data$de,"demographics.json?ip=",ip.address,"&apikey=",.InfochimpsEnv$data$api.key,sep="")
     demographics.get<-getURL(demographics.url)
     demographics.data<-fromJSON(demographics.get)
     if(is.null(demographics.data$error)) {
