@@ -14,7 +14,7 @@ function(screen.name,user.id=NA) {
         words.df<-as.data.frame(cbind(wordbag.data$user_id[[1]],words), stringsAsFactors=FALSE)
         words.names<-c("user.id","rel.freq","tok","user.freq.ppb")
         names(words.df)<-words.names
-        for(c in 1:length(word.names)) {words.df[,c]<-unlist(words.df[,c])}
+        for(c in 1:length(words.names)) {words.df[,c]<-unlist(words.df[,c])}
         words.list<-list(user.id=wordbag.data$user_id[[1]],vocab=wordbag.data$vocab[[1]],total.usages=wordbag.data$total_usages[[1]],tok.df=words.df)
         return(words.list)
     }
